pub struct PointerState {
pub location_in_window: (f64, f64),
pub location_in_canvas: Option<(f64, f64)>,
pub buttons: Vec<Button>,
pub pressure: Option<f64>,
pub tilt: Option<(f64, f64)>,
pub rotation: Option<f64>,
pub flow_rate: Option<f64>,
}Expand description
Describes the state of a pointer device
Note: while we support the various different axes that a tablet device might support, presently glutin does not provide this information to us, so these values are currently always set to ‘None’.
Fields
location_in_window: (f64, f64)The x and y coordinates of the pointer’s location in the window
location_in_canvas: Option<(f64, f64)>If the view is displaying scaled content, this is the location of the pointer in the coordinate scheme of that content
The buttons that are currently pressed down
pressure: Option<f64>If the pointer device supports pressure, the pressure the user is applying (from 0.0 to 1.0)
tilt: Option<(f64, f64)>tilt in degrees relative to the normal to the surface of the screen along the X and Y axes (values from -90 to 90)
rotation: Option<f64>If the device supports detecting rotation around its own axis, this is amount of rotation in degrees (values from -180 to 180)
flow_rate: Option<f64>If the device has a ‘flow rate’ adjustment (emulating an airbrush, for example) this is the value of that (from 0.0 to 1.0).
Implementations
Sourceimpl PointerState
impl PointerState
Sourcepub fn new() -> PointerState
pub fn new() -> PointerState
Creates a pointer state in the default state