FloWindowProperties

Trait FloWindowProperties 

pub trait FloWindowProperties {
    // Required methods
    fn title(&self) -> BindRef<String>;
    fn size(&self) -> BindRef<(u64, u64)>;
    fn fullscreen(&self) -> BindRef<bool>;
    fn has_decorations(&self) -> BindRef<bool>;
    fn mouse_pointer(&self) -> BindRef<MousePointer>;
}
Trait implemented by objects that can provide properties for creating/updating a flo_draw window

Window properties are supplied as bindings to make it possible to update them after the window has been created.

Required Methods

fn title(&self) -> BindRef<String>

The title of the window

fn size(&self) -> BindRef<(u64, u64)>

The initial size of the window

fn fullscreen(&self) -> BindRef<bool>

Set to true if the window should be fullscreen

fn has_decorations(&self) -> BindRef<bool>

Set to true if the window should have decorations

fn mouse_pointer(&self) -> BindRef<MousePointer>

The mouse pointer to show for a window

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FloWindowProperties for ()

‘()’ can be used to create a window with the default title

Source

impl<'a> FloWindowProperties for &'a str

A string can be used to set just the window title

Implementors