pub fn create_canvas_window<'a, TProperties: 'a + FloWindowProperties>(
window_properties: TProperties,
) -> CanvasExpand description
Creates a canvas that will render to a window
Canvases differ from drawing targets in that they store the vector representation of what they’re drawing, and can send their rendering to multiple targets if necessary