pub trait FloWindowProperties {
// Required methods
fn title(&self) -> BindRef<String>;
fn size(&self) -> BindRef<(u64, u64)>;
fn fullscreen(&self) -> BindRef<bool>;
fn has_decorations(&self) -> BindRef<bool>;
fn mouse_pointer(&self) -> BindRef<MousePointer>;
}Expand description
Trait implemented by objects that can provide properties for creating/updating a flo_draw window
Window properties are supplied as bindings to make it possible to update them after the window has been created.
Required Methods
Sourcefn fullscreen(&self) -> BindRef<bool>
fn fullscreen(&self) -> BindRef<bool>
Set to true if the window should be fullscreen
Sourcefn has_decorations(&self) -> BindRef<bool>
fn has_decorations(&self) -> BindRef<bool>
Set to true if the window should have decorations
Sourcefn mouse_pointer(&self) -> BindRef<MousePointer>
fn mouse_pointer(&self) -> BindRef<MousePointer>
The mouse pointer to show for a window
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl FloWindowProperties for ()
‘()’ can be used to create a window with the default title
impl FloWindowProperties for ()
‘()’ can be used to create a window with the default title
Sourceimpl<'a> FloWindowProperties for &'a str
A string can be used to set just the window title
impl<'a> FloWindowProperties for &'a str
A string can be used to set just the window title